
#ifndef SIS_WRAPPER_H_
#define SIS_WRAPPER_H_
#include <linux/fs.h>
#include <linux/mm.h>

#undef  __io_virt_debug
#define __io_virt_debug(a, f, l) (a)

#define OSS_GFP_KERNEL		0x01
#define OSS_GFP_DMA		0x02

#define WRAPPER_VERSION  1
typedef struct {int dont_try_to_use_this_field;}wait_handle;
typedef struct {int dont_try_to_use_this_field;}poll_table_handle, select_table_handle;
typedef struct {int dont_try_to_use_this_field;}pci_handle;
typedef struct {int dont_try_to_use_this_field;}file_handle;
typedef struct {int dont_try_to_use_this_field;}vm_area_handle;
typedef struct {int dont_try_to_use_this_field;}page_handle;
typedef struct {int dont_try_to_use_this_field;}inode_handle;
typedef struct {int dont_try_to_use_this_field;}dentry_handle;
typedef struct {int dont_try_to_use_this_field;}ac97_codec_handle;
typedef struct {int dont_try_to_use_this_field;}module_handle;
typedef struct {int dont_try_to_use_this_field;}dma_addr_handle;
typedef struct {int dont_try_to_use_this_field;}semaphore_handle;
typedef struct {int dont_try_to_use_this_field;}phandle;
typedef struct {int dont_try_to_use_this_field;}task_handle;

extern void * sis_pci_alloc_consistent(void *,size_t,dma_addr_handle *);

struct pci_driver_handle  {
	char * name;
	const struct pci_device_id *id_table;
	int (*probe) (void * pdev,const struct pci_device_id *);
	void (*remove) (void * pdev);
	int	(*suspend) (void * pdev,u32);
	int (*resume) (void * pdev);
};

struct driver_operations_handle {
    char		*name;
    void		*(*attach) (void *loc);
    void		(*suspend) (void *dev);
    void		(*resume) (void *dev);
    void		(*detach) (void *dev);

};

struct ac97_operation_handle {
	u16 (*ac97_read_t) (ac97_codec_handle *,u8);
	void (*ac97_write_t) (ac97_codec_handle *,u16,u8);
};

struct file_operation_handle {
#if LINUX_VERSION_CODE >= 132096 /*2.4.x*/
 	module_handle *owner;
#endif
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	long long (*lseek) (file_handle *, long long, int);
#else
	int (*lseek) (inode_handle *, file_handle *, off_t, int);
#endif
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	ssize_t (*read) (file_handle *, char *, size_t, loff_t *);
#else
	int (*read) (inode_handle *, file_handle *, char *, int);
#endif
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	ssize_t (*write) (file_handle *, const char *, size_t, loff_t *);
#else
	int (*write) (inode_handle *, file_handle *, const char *, int);
#endif
	int (*readdir) (inode_handle *, file_handle *, void *, filldir_t);
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	unsigned int (*poll) (file_handle *, poll_table_handle *);
#else
	int (*select) (inode_handle *, file_handle *, int, select_table_handle *);
#endif
	int (*ioctl) (inode_handle *, file_handle *, unsigned int, unsigned long);
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	int (*mmap) (file_handle *, vm_area_handle *);
#else
	int (*mmap) (inode_handle *, file_handle *, vm_area_handle *);
#endif
	int (*open) (inode_handle *, file_handle *);
#if LINUX_VERSION_CODE > 131328 /* 2.1.x */
	int (*release) (inode_handle *, file_handle *);
#else
	void (*release) (inode_handle *, file_handle *);
#endif
	int (*fsync) (inode_handle *, file_handle *);
	int (*fasync) (inode_handle *, file_handle *, int);
#if LINUX_VERSION_CODE<131858 /* Prior 2.3.x */
	int (*check_media_change) (kdev_t dev);
	int (*revalidate) (kdev_t dev);
#endif
}file_operation_handle;
///////////////////////////////////////////////////////
unsigned long sis_pci_resource_start(void *,int);
int sis_pci_enable_device(void *dev);
void sis_pci_set_master(void *pci_dev);
unsigned int sis_pcidev_get_irq(void *dev);
int sis_pci_request_regions(void *, char *);
void sis_pci_release_regions(void *);
void sis_pci_set_drvdata(void *ph,void *data);
void * sis_pci_get_drvdata(void *ph);

/////////////////////////////////////////////////////
void sis_netif_device_attach(void *ndev);
int sis_netif_rx(void *skb);
void sis_netdev_set_irq(void *dev,unsigned int irq);
void sis_netdev_set_last_rx(void *dev);

void * sis_netdev_get_priv(void *dev);
char * sis_netdev_get_name(void *dev);
unsigned short sis_netdev_get_flags(void *dev);
void sis_netdev_set_mtu(void *dev,unsigned mtu );
unsigned int sis_netdev_get_irq(void *dev);
unsigned char * sis_netdev_get_dev_addr(void *dev);
void sis_netdev_set_priv(void *dev,void *priv);
void sis_netdev_set_ioctl(void *dev,void *p);
void sis_netdev_set_mlist(void *dev,void *mlist);
void sis_netdev_set_gstats(void *dev,void *p);
void sis_netdev_set_stop(void *dev,void *stop);
void sis_netdev_set_xmit(void *dev,void *xmit);
void sis_netdev_set_open(void *dev,void *open);
void sis_netdev_set_gwstats(void *dev,void *p);
void sis_netdev_set_mtufun(void *dev,void *p);
void sis_netdev_set_maddr(void *dev,void *p);
void * sis_netdev_get_priv(void *dev);
void sis_unregister_netdev(void *dev);
void sis_netdev_set_trans_start(void *dev);
//////////////////////////////////////////////////////////
int sis_netif_running(void *dev);
void sis_netif_start_queue(void *dev);
void sis_netif_stop_queue(void *dev);
////////////////////////////////////////////////////
void sis_set_module_owner(void *ndev);
int sis_pci_module_init(struct pci_driver_handle *);
void sis_pci_unregister_driver(struct pci_driver_handle *);

////////////////////////////////////////////////////////////////
void sis_set_rx(unsigned long count);
void sis_set_tx(unsigned long count);
void sis_set_rxdrop(unsigned long count);
void sis_set_rxerr(unsigned long count);
void sis_set_txerr(unsigned long count);
void sis_set_rxcrcerr(unsigned long count);
void sis_set_rxbytes(unsigned long count);
void sis_set_txbytes(unsigned long count);
void *sis_get_status(void);
/////////////////////////////////////////////////////////////
void sis_dev_kfree_skb_irq(void *skb);
void sis_dev_kfree_skb_any(void *skb);
void * sis_dev_alloc_skb(unsigned int);
unsigned char * sis_skb_put(void *, unsigned int);
unsigned int sis_skb_get_len(void *);
unsigned char * sis_skb_get_data(void *);
void sis_skb_set_dev(void *skb,void * dev);
void sis_skb_set_protocol(void *skb,unsigned short);
void sis_skb_set_ip_summed(void *skb,unsigned char);
////////////////////////////////////////////////////////////
void * sis_memset(void *,int ,size_t);
void * sis_memcpy(void *,void *,size_t);
void * sis_kmalloc(unsigned long,int);
void sis_kfree(void *);
//////////////////////////////////////////////////////
void sis_udelay(unsigned long delay);
/////////////////////////////////////////////////
int sis_printk(const char *);
////////////////////////////////////////////////
unsigned short sis_eth_type_trans(void *skb, void *dev);
//////////////////////////////////////////////////////////
void sis_spin_lock(void *);
void sis_spin_unlock(void *);
void sis_spin_lock_irqsave(void *,unsigned long *);
void sis_spin_unlock_irqrestore(void *,unsigned long *);
/////////////////////////////////////////////////////////////
void sis_tq_set(void *);
void sis_queue_task(void);
void sis_run_task_queue(void); 
#endif
